@@ -12,6 +12,7 @@ import (
 	pcmd "github.com/confluentinc/cli/v3/pkg/cmd"
 	"github.com/confluentinc/cli/v3/pkg/examples"
 	"github.com/confluentinc/cli/v3/pkg/output"
+	"github.com/confluentinc/cli/v3/pkg/utils"
 )
 
 type pluginCreateOut struct {
@@ -72,14 +73,14 @@ func (c *command) createArtifact(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	if err := uploadFile(resp.GetUploadUrl(), artifactFile, resp.GetUploadFormData()); err != nil {
+	if err := utils.UploadFile(resp.GetUploadUrl(), artifactFile, resp.GetUploadFormData()); err != nil {
 		return err
 	}
 
 	createArtifactRequest := connectcustompluginv1.ConnectV1CustomConnectorPlugin{
 		DisplayName:   connectcustompluginv1.PtrString(displayName),
 		Description:   connectcustompluginv1.PtrString(description),
-		ConnectorType: connectcustompluginv1.PtrString("flink-udf"),
+		ConnectorType: connectcustompluginv1.PtrString("flink_udf"),
 		UploadSource: &connectcustompluginv1.ConnectV1CustomConnectorPluginUploadSourceOneOf{
 			ConnectV1UploadSourcePresignedUrl: &connectcustompluginv1.ConnectV1UploadSourcePresignedUrl{
 				Location: "PRESIGNED_URL_LOCATION",
