@@ -4,8 +4,7 @@ import (
 	"context"
 	"fmt"
 
-	"github.com/docker/docker/api/types"
-	containertypes "github.com/docker/docker/api/types/container"
+	"github.com/docker/docker/api/types/container"
 	"github.com/docker/docker/client"
 	"github.com/spf13/cobra"
 
@@ -37,25 +36,25 @@ func (c *command) kafkaStop(_ *cobra.Command, _ []string) error {
 }
 
 func (c *command) stopAndRemoveConfluentLocal(dockerClient *client.Client) error {
-	containers, err := dockerClient.ContainerList(context.Background(), types.ContainerListOptions{All: true})
+	dockerContainers, err := dockerClient.ContainerList(context.Background(), container.ListOptions{All: true})
 	if err != nil {
 		return err
 	}
 
-	for _, container := range containers {
-		if container.Image == dockerImageName {
-			log.CliLogger.Tracef("Stopping Confluent Local container " + getShortenedContainerId(container.ID))
+	for _, dockerContainer := range dockerContainers {
+		if dockerContainer.Image == dockerImageName {
+			log.CliLogger.Tracef("Stopping Confluent Local container " + getShortenedContainerId(dockerContainer.ID))
 			noWaitTimeout := 0 // to not wait for the container to exit gracefully
-			if err := dockerClient.ContainerStop(context.Background(), container.ID, containertypes.StopOptions{Timeout: &noWaitTimeout}); err != nil {
+			if err := dockerClient.ContainerStop(context.Background(), dockerContainer.ID, container.StopOptions{Timeout: &noWaitTimeout}); err != nil {
 				return err
 			}
 			log.CliLogger.Tracef("Confluent Local container stopped")
-			if err := dockerClient.ContainerRemove(context.Background(), container.ID, types.ContainerRemoveOptions{Force: true}); err != nil {
+			if err := dockerClient.ContainerRemove(context.Background(), dockerContainer.ID, container.RemoveOptions{Force: true}); err != nil {
 				return err
 			}
 			log.CliLogger.Tracef("Confluent Local container removed")
 
-			output.Printf(c.Config.EnableColor, "Confluent Local has been stopped: removed container \"%s\".\n", getShortenedContainerId(container.ID))
+			output.Printf(c.Config.EnableColor, "Confluent Local has been stopped: removed container \"%s\".\n", getShortenedContainerId(dockerContainer.ID))
 		}
 	}
 
