@@ -3,20 +3,20 @@ package cmd
 import (
 	"github.com/spf13/cobra"
 
-	dynamicconfig "github.com/confluentinc/cli/v3/pkg/dynamic-config"
+	"github.com/confluentinc/cli/v3/pkg/config"
 	"github.com/confluentinc/cli/v3/pkg/version"
 )
 
 type CLICommand struct {
 	*cobra.Command
-	Config  *dynamicconfig.DynamicConfig
+	Config  *config.Config
 	Version *version.Version
 }
 
 func NewCLICommand(cmd *cobra.Command) *CLICommand {
 	return &CLICommand{
 		Command: cmd,
-		Config:  &dynamicconfig.DynamicConfig{},
+		Config:  &config.Config{},
 	}
 }
 
