@@ -42,6 +42,9 @@ const (
 	KsqlCluster                     = "KSQL cluster"
 	MirrorTopic                     = "mirror topic"
 	Network                         = "network"
+	NetworkLinkEndpoint             = "network link endpoint"
+	NetworkLinkService              = "network link service"
+	NetworkLinkServiceAssociation   = "network link service association"
 	Organization                    = "organization"
 	Peering                         = "peering"
 	PrivateLinkAccess               = "private link access"
